@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -154,11 +152,9 @@ class AlarmServiceView(tables.DataTableView):
                 try:
                     name, value = self.service.split("=")
                     results = [api.monitor.alarm_show(self.request, value)]
-                except Exception as e:
+                except Exception:
                     messages.error(self.request, _("Could not retrieve alarms"))
                     results = []
-                    print "ERROR"
-                    print e
                 return results
             else:
                 try:
@@ -209,7 +205,7 @@ class AlarmServiceView(tables.DataTableView):
                 try:
                     name, value = self.service.split("=")
                     results = [api.monitor.alarm_show(self.request, value)]
-                except Exception as e:
+                except Exception:
                     messages.error(self.request, _("Could not retrieve alarms"))
                     results = []
             else:
@@ -301,9 +297,9 @@ class AlarmHistoryView(tables.DataTableView):
         limit = utils.get_page_size(self.request)
         try:
             results = api.monitor.alarm_history(self.request,
-                                                object_id,
-                                                page_offset,
-                                                limit)
+                                            object_id,
+                                            page_offset,
+                                            limit)
             paginator = Paginator(results, limit)
             contacts = paginator.page(1)
         except EmptyPage:
