@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,10 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from django.core import urlresolvers
 from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ungettext_lazy
 
 from horizon import exceptions
 from horizon import tables
@@ -25,14 +22,26 @@ from horizon import tables
 from monitoring import api
 from monitoring.notifications import constants
 
-LOG = logging.getLogger(__name__)
-
 
 class DeleteNotification(tables.DeleteAction):
     name = "delete_notification"
     verbose_name = _("Delete Notification")
-    data_type_singular = _("Notification")
-    data_type_plural = _("Notifications")
+
+    @staticmethod
+    def action_present(count):
+        return ungettext_lazy(
+            u"Delete Notification",
+            u"Delete Notifications",
+            count
+        )
+
+    @staticmethod
+    def action_past(count):
+        return ungettext_lazy(
+            u"Deleted Notification",
+            u"Deleted Notifications",
+            count
+        )
 
     def allowed(self, request, datum=None):
         return True
